==> mpsplots-1.4.13.post0.tar.gz: mpsplots-1.4.13.post0/docs/source/conf.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
from sphinx_gallery.sorting import FileNameSortKey
from packaging.version import parse
from MPSPlots.styles import use_mpsplots_style
import MPSPlots
from MPSPlots.tools.directories import project_path, doc_css_path

sys.path.insert(0, project_path)
sys.path.insert(0, os.path.join(project_path, "MPSPlots"))


def setup(app):
    app.add_css_file(str(doc_css_path))


autodoc_mock_imports = [
    'numpy',
    'matplotlib',
    'pyvista'
]

project = 'MPSPlots'
copyright = '2021, Martin Poinsinet de Sivry-Houle'
author = 'Martin Poinsinet de Sivry-Houle'
today_fmt = '%B %d, %Y'

version = MPSPlots.__version__


extensions = [
    'sphinx.ext.mathjax',
    'numpydoc',
    "pyvista.ext.plot_directive",
    'sphinx_gallery.gen_gallery',
]


def reset_mpl(gallery_conf, fname):
    use_mpsplots_style()


try:
    import pyvista
    pyvista.start_xvfb()  # Works only on linux system!
except:
    print('Could not load pyvista library for 3D rendering')


sphinx_gallery_conf = {
    'examples_dirs': '../examples',
    'gallery_dirs': "gallery",
    'image_scrapers': ('matplotlib', 'pyvista'),
    'ignore_pattern': '/__',
    'plot_gallery': True,
    'thumbnail_size': [600, 600],
    'download_all_examples': False,
    'reset_modules': reset_mpl,
    'line_numbers': False,
    'remove_config_comments': True,
    'within_subsection_order': FileNameSortKey,
    'capture_repr': ('_repr_html_', '__repr__'),
    'nested_sections': True,
}

autodoc_default_options = {
    'members': False,
    'members-order': 'bysource',
    'undoc-members': False,
    'show-inheritance': True,
}

numpydoc_show_class_members = False

source_suffix = '.rst'

master_doc = 'index'

language = 'en'

exclude_patterns = []

pygments_style = 'monokai'

highlight_language = 'python3'

html_theme = "pydata_sphinx_theme"

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

exclude_trees = []
default_role = "autolink"
pygments_style = "sphinx"

# -- Sphinx-gallery configuration --------------------------------------------
major, minor = version[:2]
binder_branch = f"v{major}.{minor}.x"

html_theme_options = {
    # Navigation bar
    "logo": {
        "alt_text": "MPSPlots's logo",
        "text": "MPSPlots",
        "link": "https://github.com/MartinPdeS/MPSPlots",
    },
    "icon_links": [
        {
            "name": "GitHub",
            "url": "https://github.com/MartinPdeS/MPSPlots",
            "icon": "fa-brands fa-github",
        },
        {
            "name": "PyPI",
            "url": "https://pypi.org/project/mpsplots/",
            "icon": "fa-solid fa-box",
        },
    ],
    "navbar_align": "left",
    "navbar_end": ["version-switcher", "navbar-icon-links"],
    "show_prev_next": False,
    "show_version_warning_banner": True,
    # Footer
    "footer_start": ["copyright"],
    "footer_end": ["sphinx-version", "theme-version"],
    # Other
    "pygment_light_style": "default",
    "pygment_dark_style": "github-dark",
}


htmlhelp_basename = 'MPSPlotsdoc'

latex_elements = {}

latex_documents = [
    (master_doc, 'MPSPlots.tex', 'MPSPlots Documentation',
     'Martin Poinsinet de Sivry-Houle', 'manual'),
]

man_pages = [
    (master_doc, 'pymiesim', 'MPSPlots Documentation',
     [author], 1)
]

texinfo_documents = [
    (master_doc, 'MPSPlots', 'MPSPlots Documentation',
     author, 'MPSPlots', 'One line description of project.',
     'Miscellaneous'),
]

epub_title = project

html_static_path = ['_static']
html_css_files = ['default.css']
epub_exclude_files = ['search.html']

==> mpsplots-1.5.2.post0.tar.gz: mpsplots-1.5.2.post0/docs/source/conf.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import MPSPlots
from sphinx_gallery.sorting import FileNameSortKey
from MPSPlots.styles import use_mpsplots_style
from MPSPlots.directories import project_path, doc_css_path

sys.path.insert(0, project_path)
sys.path.insert(0, os.path.join(project_path, "MPSPlots"))


def setup(app):
    app.add_css_file(str(doc_css_path))


autodoc_mock_imports = [
    'numpy',
    'matplotlib',
    'pyvista'
]

project = 'MPSPlots'
copyright = '2021, Martin Poinsinet de Sivry-Houle'
author = 'Martin Poinsinet de Sivry-Houle'
today_fmt = '%B %d, %Y'

version = MPSPlots.__version__


extensions = [
    'sphinx.ext.mathjax',
    'pyvista.ext.plot_directive',
    'sphinx_gallery.gen_gallery',
    'sphinx.ext.autodoc',
    'sphinx.ext.napoleon',
    'sphinx.ext.viewcode',
    'sphinx.ext.autosectionlabel',
    'sphinx.ext.intersphinx',
]

# Napoleon settings for docstrings
napoleon_google_docstring = False
napoleon_numpy_docstring = True


def reset_mpl(gallery_conf, fname):
    use_mpsplots_style()


try:
    import pyvista
    pyvista.start_xvfb()  # Works only on linux system!
except:
    print('Could not load pyvista library for 3D rendering')


sphinx_gallery_conf = {
    'examples_dirs': '../examples',
    'gallery_dirs': "gallery",
    'image_scrapers': ('matplotlib', 'pyvista'),
    'ignore_pattern': '/__',
    'plot_gallery': True,
    'thumbnail_size': [600, 600],
    'download_all_examples': False,
    'reset_modules': reset_mpl,
    'line_numbers': False,
    'remove_config_comments': True,
    'within_subsection_order': FileNameSortKey,
    'capture_repr': ('_repr_html_', '__repr__'),
    'nested_sections': True,
}

autodoc_default_options = {
    'members': False,
    'members-order': 'bysource',
    'undoc-members': False,
    'show-inheritance': True,
}



autosectionlabel_prefix_document = True
numpydoc_show_class_members = False
add_module_names = False


source_suffix = '.rst'
master_doc = 'index'
language = 'en'
highlight_language = 'python3'
html_theme = "pydata_sphinx_theme"

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

exclude_trees = []
# default_role = "autolink"
pygments_style = "sphinx"

# -- Sphinx-gallery configuration --------------------------------------------
major, minor = version[:2]
binder_branch = f"v{major}.{minor}.x"

html_theme_options = {
    # Navigation bar
    "logo": {
        "alt_text": "MPSPlots's logo",
        "text": "MPSPlots",
        "link": "https://github.com/MartinPdeS/MPSPlots",
    },
    "icon_links": [
        {
            "name": "GitHub",
            "url": "https://github.com/MartinPdeS/MPSPlots",
            "icon": "fa-brands fa-github",
        },
        {
            "name": "PyPI",
            "url": "https://pypi.org/project/mpsplots/",
            "icon": "fa-solid fa-box",
        },
        {
            "name": "Anaconda",
            "url": "https://anaconda.org/MartinPdeS/mpsplots",
            "icon": "fa-brands fa-python",
        },
    ],
    "navbar_align": "left",
    "navbar_end": ["version-switcher", "navbar-icon-links"],
    "show_prev_next": False,
    "show_version_warning_banner": True,
    # Footer
    "footer_start": ["copyright"],
    "footer_end": ["sphinx-version", "theme-version"],
    # Other
    "pygment_light_style": "default",
    "pygment_dark_style": "github-dark",
}


htmlhelp_basename = 'MPSPlotsdoc'

latex_elements = {}

latex_documents = [
    (master_doc, 'MPSPlots.tex', 'MPSPlots Documentation',
     'Martin Poinsinet de Sivry-Houle', 'manual'),
]

man_pages = [
    (master_doc, 'pymiesim', 'MPSPlots Documentation',
     [author], 1)
]

texinfo_documents = [
    (master_doc, 'MPSPlots', 'MPSPlots Documentation',
     author, 'MPSPlots', 'One line description of project.',
     'Miscellaneous'),
]

epub_title = project

html_static_path = ['_static']
templates_path = ['_templates']
html_css_files = ['default.css']
epub_exclude_files = ['search.html']
